# git-ignore [![Crates.io](https://img.shields.io/crates/v/git-ignore-generator.svg)](https://crates.io/crates/git-ignore-generator) ![pipeline](https://github.com/sondr3/git-ignore/workflows/pipeline/badge.svg)

## What and why

Far too often I find myself going to [gitignore.io](https://www.gitignore.io/)
to quickly get `.gitignore` templates for my projects, so what would any
reasonable programmer do for repetitive tasks?
[Automate](https://xkcd.com/1319/) [it](https://xkcd.com/1205/)! Now you can
quickly and easily get and list all the templates available on gitignore.io, it
even works offline by caching the templates!

# Installation

There are a couple of ways of installing it. See installation and usage
instructions below.

## Cargo

`cargo install git-ignore-generator`.

## Nix

Run `nix-env -iA nixpkgs.gitAndTools.git-ignore`. This includes man pages.

## Homebrew

Add my personal Homebrew taps repository with `brew tap sondr3/homebrew-taps`
and then install it with `brew install git-ignore`. This includes man pages.

## Arch

It's available as a binary package from
[AUR](https://aur.archlinux.org/packages/git-ignore-bin/). Install it with your
favorite AUR helper. `yay git-ignore`. This includes man pages.

## Release pages

You can also download the matching release from the [release
tab](https://github.com/sondr3/git-ignore/releases), extracting the archive and
placing the binary in your `$PATH`. Note that for Linux the
`unknown-linux-musl.tar.gz` is preferred as it is statically linked and thus
should run on any Linux distribution.

# Usage

To download and cache all available templates, use `--update`. This can also be
used in combination with any of the other flags/arguments, or be ran as a
standalone flag.

``` sh
$ git ignore -u
```

To list all the available templates:

```sh
$ git ignore --list
[
    "1c",
    "1c-bitrix",
    "a-frame",
    "actionscript",
    "ada",
    [...],
    "zukencr8000"
]
```

You can also search for templates with the `--list` flag. **Note**: Listing
templates doesn't require exact matches, any template matching the start of your
query will be matched. See the example below for this, `intellij` matches all
three templates starting with `intellij`:

```sh
$ git ignore rust intellij --list
[
    "intellij",
    "intellij+all",
    "intellij+iml",
    "rust"
]
```

Then you can print the templates by omitting `--list`. **Note:** While listing
do not require exact matches, printing templates do. Use `--list` to find
templates. There will also be a notice about using cached results, this is
printed to `stderr` as to not interfere with piping.

```sh
$ git ignore rust intellij+all

### Created by https://www.gitignore.io
### Rust ###

[...]

# These are backup files generated by rustfmt
**/*.rs.bk
```

Finally, help is always available with `git ignore -h` (or `--help` if you used
Nix). 
